# 1 "src/batSeq.mliv"
(*
 * Copyright (C) 2009 Jeremie Dimino
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version,
 * with the special exception on linking described in file LICENSE.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *)

(** Sequence of elements *)

(** A sequence represent a collection of elements, for which you never
    construct the complete representation.

    Basically you should use a sequence when you would prefer using a
    list or a lazy-list but constructing the whole list explicitly
    would explode your memory.

    All functions returning a sequence operates in time and space
    O(1).

    Note that if you want a ``consumable sequence'', you should prefer
    using enumerations (from module {!BatEnum}).

    @author Jeremie Dimino
*)

# 39 "src/batSeq.mliv"
 type 'a t = 'a Stdlib.Seq.t
(** A sequence is a computation which returns a list-like node *)

and 'a node =
 'a Stdlib.Seq.node =
  | Nil
  | Cons of 'a * 'a t

include BatInterfaces.Mappable with type 'a mappable = 'a t

val enum : 'a t -> 'a BatEnum.t
(** [enum s] returns the enumeration of all element of [s].

    Since enumerations are consumable and sequence are not, it is
    not possible to have the inverse operations, i.e. [of_enum] *)

(** {6 Base operations} *)

val length : 'a t -> int
(** Return the number of elements of the given sequence. This may
    never return if the sequence is infinite. *)

val hd : 'a t -> 'a
(** Returns the first element of the sequence or raise [Invalid_argument] if
    the sequence is empty. *)

val tl : 'a t -> 'a t
(** Returns the sequence without its first elements or raise
    [Invalid_argument] if the sequence is empty. *)

val is_empty : 'a t -> bool
(** [is_empty e] returns true if [e] does not contains any
    element. *)

val first : 'a t -> 'a
(** Same as {!hd} *)

val last : 'a t -> 'a
(** Returns the last element of the sequence, or raise [Invalid_argument] if
    the sequence is empty. *)

val at : 'a t -> int -> 'a
(** [at l n] returns the element at index [n] (starting from [0]) in
    the sequence [l] or raise [Invalid_argument] is the index is
    outside of [l] bounds. *)

val append : 'a t -> 'a t -> 'a t
(** [append s1 s2] returns the sequence which first returns all
    elements of [s1] then all elements of [s2]. *)

val concat : 'a t t -> 'a t
(** [concat s] returns the sequence which returns all the elements
    of all the elements of [s], in the same order. *)

val flatten : 'a t t -> 'a t
(** Same as {!concat}. *)

(** {6 Constructors} *)

val nil : 'a t
(** [nil = fun () -> Nil] *)

val empty : 'a t
(** the empty sequence, containing no elements

    @since 3.3.0 *)

val return : 'a -> 'a t
(** the singleton sequence, containing only the given element

    @since 3.3.0 *)

val cons : 'a -> 'a t -> 'a t
(** [cons e s = fun () -> Cons(e, s)] *)

val make : int -> 'a -> 'a t
(** [make n e] returns the sequence of length [n] where all elements
    are [e] *)

val init : int -> (int -> 'a) -> 'a t
(** [init n f] returns the sequence returning the results of [f 0],
    [f 1].... [f (n-1)]. @raise Invalid_argument if [n < 0]. *)

val of_list : 'a list -> 'a t
(** Convenience function to build a seq from a list.
    @since 2.2.0 *)

val unfold : ('b -> ('a * 'b) option) -> 'b -> 'a t
(** Build a sequence from a step function and an initial value.
    [unfold f u] returns [empty] if [f u] returns [None],
    or [fun () -> Cons (x, unfold f y)] if [f u] returns [Some (x, y)].

    For example, [unfold (function [] -> None | h::t -> Some (h,t)) l]
    is equivalent to [List.to_seq l].

    @since 3.3.0 *)

val flat_map : ('a -> 'b t) -> 'a t -> 'b t
(** Map each element to a subsequence, then return each element of this
    sub-sequence in turn. This transformation is lazy, it only applies
    when the result is traversed.

    @since 3.3.0 *)

val concat_map: ('a -> 'b t) -> 'a t -> 'b t
(** Alias for {!flat_map}.
    @since 3.4.0 *)

(** {6 Iterators} *)

val iter : ('a -> unit) -> 'a t -> unit
(** [iter f s] applies [f] to all the elements of the sequence. Eager. *)

val iteri : (int -> 'a -> unit) -> 'a t -> unit
(** [iteri f s] is the same as [iter f s], but [f] is given the index
    of each element (starting at 0).
    @since 2.2.0 *)

val iter2 : ('a -> 'b -> unit) -> 'a t -> 'b t -> unit
(** [iter2 f s1 s2] iterates on elements of [s1] and [s2] pairwise, and
    stops when it meets the end of [s1] or [s2]
    @since 2.2.0 *)

val map : ('a -> 'b) -> 'a t -> 'b t
(** [map f s] returns the sequence where elements are elements of
    [s] mapped with [f]. Lazy. *)

val mapi : (int -> 'a -> 'b) -> 'a t -> 'b t
(** [mapi f s] lazily maps elements of [s] into a new sequence,
    using [f]. [f] is also given elements' indexes.
    @since 2.2.0 *)

val map2 : ('a -> 'b -> 'c) -> 'a t -> 'b t -> 'c t
(** [map2 f s1 s2] returns a sequence of elements, resulting from combininig
    elements of [s1] and [s2] at the same index using [f]. The result is as
    long as the shortest argument.
    @since 2.2.0 *)

val fold_left : ('a -> 'b -> 'a) -> 'a -> 'b t -> 'a
(** [fold_left f a (cons b0 (... bn))] is [f (... (f (f a b0) b1) ...)
    bn]. Tail-recursive, eager.
*)

val fold_right : ('a -> 'b -> 'b) -> 'a t -> 'b -> 'b
(** [fold_right f (cons a0 (cons a1 (cons a2 ...))) b] is [f a0 (f
    a1 (f a2 ...))].
    Not tail-recursive, eager.
*)

val reduce : ('a -> 'a -> 'a) -> 'a t -> 'a
(** [reduce f (cons e s)] is [fold_left f e s].

    @raise Invalid_argument on empty sequences. *)

val max : 'a t -> 'a
(** [max s] returns the largest value in [s] as judged by
    [Pervasives.compare]

    @raise Invalid_argument on empty sequences. *)

val min : 'a t -> 'a
(** [min s] returns the smallest value in [s] as judged by
    [Pervasives.compare]

    @raise Invalid_argument on empty sequences. *)

val equal : ?eq:('a -> 'a -> bool) -> 'a t -> 'a t -> bool
  (** [equal ~eq s1 s2] compares elements of [s1] and [s2] pairwise
      using [eq]
      @param eq optional equality function (default {!Pervasives.(=)})
      @since 2.2.0 *)

(** {6 Sequence scanning}

    Most functions in the following sections have a shortcut semantic
    similar to the behavior of the usual (&&) and (||) operators :
    they will force the sequence until they find an satisfying
    element, and then return immediately.

    For example, [for_all] will only diverge if the sequence begins
    with an infinite number of true elements --- elements for which
    the predicate [p] returns [true].
*)

val for_all : ('a -> bool) -> 'a t -> bool
(** [for_all p (cons a0 (cons a1 ...))] checks if all elements of the
    given sequence satisfy the predicate [p]. That is, it returns
    [(p a0) && (p a1) && ...]. Eager, shortcut.
*)

val exists : ('a -> bool) -> 'a t -> bool
(** [exists p (cons a0 (cons a1 ...))] checks if at least one element of
    the sequence satisfies the predicate [p]. That is, it returns
    [(p a0) || (p a1) || ...]. Eager, shortcut.
*)

val mem : 'a -> 'a t -> bool
(** [mem a l] is true if and only if [a] is equal to an element of
    [l]. Eager, shortcut.
*)

(** {6 Sequence searching} *)

val find : ('a -> bool) -> 'a t -> 'a option
(** [find p s] returns the first element of [s] such as [p e]
    returns [true], if any. Eager, shortcut.
*)

val find_map : ('a -> 'b option) -> 'a t -> 'b option
(** [find_map p s] finds the first element of [s] for which [p e]
    returns [Some r], if any. Eager, short-cut.
*)

val filter : ('a -> bool) -> 'a t -> 'a t
(** [filter p s] returns the sequence of elements of [s] satisfying
    [p]. Lazy.

    {b Note} filter is lazy in that it returns a lazy sequence, but
    each element in the result is eagerly searched in the input
    sequence. Therefore, the access to a given element in the result
    will diverge if it is preceded, in the input sequence, by
    infinitely many false elements (elements on which the predicate
    [p] returns [false]).

    Other functions that may drop an unbound number of elements
    ([filter_map], [take_while], etc.) have the same behavior.
*)

val filter_map : ('a -> 'b option) -> 'a t -> 'b t
(** [filter_map f s] returns the sequence of elements filtered and
    mapped by [f]. Lazy.
*)

(** {6 Association sequences} *)

val assoc : 'a -> ('a * 'b) t -> 'b option
(** [assoc a s] returns the value associated with key [a] in the
    sequence of pairs [s]. Eager, shortcut.  *)

(** {6 Sequence transformations} *)

val take : int -> 'a t -> 'a t
(** [take n s] returns up to the [n] first elements from sequence
    [s], if available. Lazy. *)

val drop : int -> 'a t -> 'a t
(** [drop n s] returns [s] without the first [n] elements, or the
    empty sequence if [s] have less than [n] elements. Lazy. *)

val take_while : ('a -> bool) -> 'a t -> 'a t
(** [take_while f s] returns the first elements of sequence [s]
    which satisfy the predicate [f]. Lazy. *)

val drop_while : ('a -> bool) -> 'a t -> 'a t
(** [drop_while f s] returns the sequence [s] with the first
    elements satisfying the predicate [f] dropped. Lazy. *)

(** {6 Sequence of pairs} *)

val split : ('a * 'b) t -> 'a t * 'b t
(** [split s = (map fst s, map snd s)]. Lazy. *)

val combine : 'a t -> 'b t -> ('a * 'b) t
(** Transform a pair of sequences into a sequence of pairs. Lazy.

    @raise Invalid_argument if given sequences of different length. *)

(** {6 Printing} *)

val print : ?first:string -> ?last:string -> ?sep:string -> ('a BatInnerIO.output -> 'b -> unit) ->  'a BatInnerIO.output -> 'b t -> unit
(**Print the contents of a sequence*)

val to_buffer : ?first:string -> ?last:string -> ?sep:string -> ('a -> string) -> Buffer.t -> (unit -> 'a node) -> unit
(** Convert a sequence to a string in the given buffer; eager.
    @since 2.10.0
*)

val to_string : ?first:string -> ?last:string -> ?sep:string -> ('a -> string) -> 'a t -> string
(** Convert the sequence to a string; eager.
    @since 2.10.0
*)

val of_string : ?first:string -> ?last:string -> ?sep:string -> (string -> 'a) -> string -> 'a t
(** Create a sequence by parsing a string.
    @raise Invalid_argument if the string is not prefixed by [first].
    @raise Invalid_argument if the string is not suffixed by [last].
    @since 2.10.0
*)

module Infix : sig
  (** Infix operators matching those provided by {!BatEnum.Infix} *)

  val ( -- ) : int -> int -> int t
  val ( --^ ) : int -> int -> int t
  val ( --. ) : float * float -> float -> float t
  val ( --- ) : int -> int -> int t
  val ( --~ ) : char -> char -> char t
  val ( // ) : 'a t -> ('a -> bool) -> 'a t
  val ( /@ ) : 'a t -> ('a -> 'b) -> 'b t
  val ( @/ ) : ('a -> 'b) -> 'a t -> 'b t
  val ( //@ ) : 'a t -> ('a -> 'b option) -> 'b t
  val ( @// ) : ('a -> 'b option) -> 'a t -> 'b t
end

include module type of Infix

module Exceptionless : sig
  val hd : 'a t -> 'a option
  val tl : 'a t -> 'a t option
  val first : 'a t -> 'a option
  val last : 'a t -> 'a option
  val at : 'a t -> int -> 'a option
  (*
  val make : int -> 'a -> 'a t
  val init : int -> (int -> 'a) -> 'a t
  *)
  val reduce : ('a -> 'a -> 'a) -> 'a t -> 'a option
  val max : 'a t -> 'a option
  val min : 'a t -> 'a option
  val combine : 'a t -> 'b t -> ('a * 'b) t
end

# 362 "src/batSeq.mliv"
# 363 "src/batSeq.mliv"
# 364 "src/batSeq.mliv"
# 365 "src/batSeq.mliv"
# 366 "src/batSeq.mliv"
# 367 "src/batSeq.mliv"
# 368 "src/batSeq.mliv"
# 369 "src/batSeq.mliv"
# 370 "src/batSeq.mliv"

# 372 "src/batSeq.mliv"
# 373 "src/batSeq.mliv"
# 374 "src/batSeq.mliv"
# 375 "src/batSeq.mliv"
# 376 "src/batSeq.mliv"
# 377 "src/batSeq.mliv"
# 378 "src/batSeq.mliv"
# 379 "src/batSeq.mliv"
# 380 "src/batSeq.mliv"
# 381 "src/batSeq.mliv"
# 382 "src/batSeq.mliv"
# 383 "src/batSeq.mliv"
# 384 "src/batSeq.mliv"

# 386 "src/batSeq.mliv"
# 387 "src/batSeq.mliv"
# 388 "src/batSeq.mliv"
# 389 "src/batSeq.mliv"
# 390 "src/batSeq.mliv"
# 391 "src/batSeq.mliv"

# 393 "src/batSeq.mliv"
# 394 "src/batSeq.mliv"
# 395 "src/batSeq.mliv"
# 396 "src/batSeq.mliv"
# 397 "src/batSeq.mliv"
# 398 "src/batSeq.mliv"
# 399 "src/batSeq.mliv"
# 400 "src/batSeq.mliv"
# 401 "src/batSeq.mliv"
# 402 "src/batSeq.mliv"

# 404 "src/batSeq.mliv"
# 405 "src/batSeq.mliv"
# 406 "src/batSeq.mliv"
# 407 "src/batSeq.mliv"
# 408 "src/batSeq.mliv"
# 409 "src/batSeq.mliv"
# 410 "src/batSeq.mliv"
# 411 "src/batSeq.mliv"
# 412 "src/batSeq.mliv"
# 413 "src/batSeq.mliv"
# 414 "src/batSeq.mliv"
# 415 "src/batSeq.mliv"

# 417 "src/batSeq.mliv"
# 418 "src/batSeq.mliv"
# 419 "src/batSeq.mliv"
# 420 "src/batSeq.mliv"
# 421 "src/batSeq.mliv"
# 422 "src/batSeq.mliv"
# 423 "src/batSeq.mliv"

# 425 "src/batSeq.mliv"
# 426 "src/batSeq.mliv"
# 427 "src/batSeq.mliv"
# 428 "src/batSeq.mliv"
# 429 "src/batSeq.mliv"
# 430 "src/batSeq.mliv"
# 431 "src/batSeq.mliv"

# 433 "src/batSeq.mliv"
# 434 "src/batSeq.mliv"
# 435 "src/batSeq.mliv"
# 436 "src/batSeq.mliv"
# 437 "src/batSeq.mliv"
# 438 "src/batSeq.mliv"
# 439 "src/batSeq.mliv"
# 440 "src/batSeq.mliv"
# 441 "src/batSeq.mliv"

# 443 "src/batSeq.mliv"
# 444 "src/batSeq.mliv"
# 445 "src/batSeq.mliv"
# 446 "src/batSeq.mliv"
# 447 "src/batSeq.mliv"
# 448 "src/batSeq.mliv"
# 449 "src/batSeq.mliv"
# 450 "src/batSeq.mliv"
# 451 "src/batSeq.mliv"
# 452 "src/batSeq.mliv"

# 454 "src/batSeq.mliv"
# 455 "src/batSeq.mliv"
# 456 "src/batSeq.mliv"
# 457 "src/batSeq.mliv"
# 458 "src/batSeq.mliv"
# 459 "src/batSeq.mliv"
# 460 "src/batSeq.mliv"
# 461 "src/batSeq.mliv"
# 462 "src/batSeq.mliv"
# 463 "src/batSeq.mliv"
# 464 "src/batSeq.mliv"
# 465 "src/batSeq.mliv"
# 466 "src/batSeq.mliv"
# 467 "src/batSeq.mliv"
# 468 "src/batSeq.mliv"

# 470 "src/batSeq.mliv"
# 471 "src/batSeq.mliv"
# 472 "src/batSeq.mliv"
# 473 "src/batSeq.mliv"
# 474 "src/batSeq.mliv"
# 475 "src/batSeq.mliv"
# 476 "src/batSeq.mliv"
# 477 "src/batSeq.mliv"
# 478 "src/batSeq.mliv"
# 479 "src/batSeq.mliv"
# 480 "src/batSeq.mliv"
# 481 "src/batSeq.mliv"
# 482 "src/batSeq.mliv"
# 483 "src/batSeq.mliv"
# 484 "src/batSeq.mliv"
# 485 "src/batSeq.mliv"
# 486 "src/batSeq.mliv"
# 487 "src/batSeq.mliv"

# 489 "src/batSeq.mliv"
# 490 "src/batSeq.mliv"
# 491 "src/batSeq.mliv"
# 492 "src/batSeq.mliv"
# 493 "src/batSeq.mliv"
# 494 "src/batSeq.mliv"
# 495 "src/batSeq.mliv"
# 496 "src/batSeq.mliv"
# 497 "src/batSeq.mliv"
# 498 "src/batSeq.mliv"
# 499 "src/batSeq.mliv"
# 500 "src/batSeq.mliv"
# 501 "src/batSeq.mliv"
# 502 "src/batSeq.mliv"
# 503 "src/batSeq.mliv"
# 504 "src/batSeq.mliv"
# 505 "src/batSeq.mliv"

# 507 "src/batSeq.mliv"
# 508 "src/batSeq.mliv"
# 509 "src/batSeq.mliv"
# 510 "src/batSeq.mliv"
# 511 "src/batSeq.mliv"
# 512 "src/batSeq.mliv"
# 513 "src/batSeq.mliv"
# 514 "src/batSeq.mliv"
# 515 "src/batSeq.mliv"
# 516 "src/batSeq.mliv"
# 517 "src/batSeq.mliv"
# 518 "src/batSeq.mliv"
# 519 "src/batSeq.mliv"

# 521 "src/batSeq.mliv"
# 522 "src/batSeq.mliv"
# 523 "src/batSeq.mliv"
# 524 "src/batSeq.mliv"
# 525 "src/batSeq.mliv"
# 526 "src/batSeq.mliv"
# 527 "src/batSeq.mliv"
# 528 "src/batSeq.mliv"

# 530 "src/batSeq.mliv"
# 531 "src/batSeq.mliv"
# 532 "src/batSeq.mliv"
# 533 "src/batSeq.mliv"
# 534 "src/batSeq.mliv"
# 535 "src/batSeq.mliv"
# 536 "src/batSeq.mliv"
# 537 "src/batSeq.mliv"
# 538 "src/batSeq.mliv"
# 539 "src/batSeq.mliv"

# 541 "src/batSeq.mliv"
# 542 "src/batSeq.mliv"
# 543 "src/batSeq.mliv"
# 544 "src/batSeq.mliv"
# 545 "src/batSeq.mliv"
# 546 "src/batSeq.mliv"
# 547 "src/batSeq.mliv"
# 548 "src/batSeq.mliv"
# 549 "src/batSeq.mliv"
# 550 "src/batSeq.mliv"
# 551 "src/batSeq.mliv"

# 553 "src/batSeq.mliv"
# 554 "src/batSeq.mliv"
# 555 "src/batSeq.mliv"
# 556 "src/batSeq.mliv"
# 557 "src/batSeq.mliv"
# 558 "src/batSeq.mliv"
# 559 "src/batSeq.mliv"

# 561 "src/batSeq.mliv"
# 562 "src/batSeq.mliv"
# 563 "src/batSeq.mliv"
# 564 "src/batSeq.mliv"
# 565 "src/batSeq.mliv"
# 566 "src/batSeq.mliv"
# 567 "src/batSeq.mliv"
# 568 "src/batSeq.mliv"
# 569 "src/batSeq.mliv"
# 570 "src/batSeq.mliv"

# 572 "src/batSeq.mliv"
# 573 "src/batSeq.mliv"
# 574 "src/batSeq.mliv"
# 575 "src/batSeq.mliv"
# 576 "src/batSeq.mliv"
# 577 "src/batSeq.mliv"
# 578 "src/batSeq.mliv"
# 579 "src/batSeq.mliv"
# 580 "src/batSeq.mliv"
# 581 "src/batSeq.mliv"
# 582 "src/batSeq.mliv"
# 583 "src/batSeq.mliv"

# 585 "src/batSeq.mliv"
# 586 "src/batSeq.mliv"
# 587 "src/batSeq.mliv"
# 588 "src/batSeq.mliv"
# 589 "src/batSeq.mliv"
# 590 "src/batSeq.mliv"
# 591 "src/batSeq.mliv"
# 592 "src/batSeq.mliv"

# 594 "src/batSeq.mliv"
# 595 "src/batSeq.mliv"
# 596 "src/batSeq.mliv"
# 597 "src/batSeq.mliv"
# 598 "src/batSeq.mliv"
# 599 "src/batSeq.mliv"
# 600 "src/batSeq.mliv"

# 602 "src/batSeq.mliv"
# 603 "src/batSeq.mliv"
# 604 "src/batSeq.mliv"
# 605 "src/batSeq.mliv"
# 606 "src/batSeq.mliv"
# 607 "src/batSeq.mliv"
# 608 "src/batSeq.mliv"
# 609 "src/batSeq.mliv"
# 610 "src/batSeq.mliv"
# 611 "src/batSeq.mliv"
# 612 "src/batSeq.mliv"
# 613 "src/batSeq.mliv"
# 614 "src/batSeq.mliv"
# 615 "src/batSeq.mliv"
# 616 "src/batSeq.mliv"
# 617 "src/batSeq.mliv"
# 618 "src/batSeq.mliv"
# 619 "src/batSeq.mliv"

# 621 "src/batSeq.mliv"
# 622 "src/batSeq.mliv"
# 623 "src/batSeq.mliv"
# 624 "src/batSeq.mliv"
# 625 "src/batSeq.mliv"
# 626 "src/batSeq.mliv"
# 627 "src/batSeq.mliv"
# 628 "src/batSeq.mliv"
# 629 "src/batSeq.mliv"
# 630 "src/batSeq.mliv"
# 631 "src/batSeq.mliv"

# 633 "src/batSeq.mliv"
# 634 "src/batSeq.mliv"
# 635 "src/batSeq.mliv"
# 636 "src/batSeq.mliv"
# 637 "src/batSeq.mliv"
# 638 "src/batSeq.mliv"
# 639 "src/batSeq.mliv"
# 640 "src/batSeq.mliv"
# 641 "src/batSeq.mliv"
# 642 "src/batSeq.mliv"
# 643 "src/batSeq.mliv"
# 644 "src/batSeq.mliv"
# 645 "src/batSeq.mliv"
# 646 "src/batSeq.mliv"
# 647 "src/batSeq.mliv"
# 648 "src/batSeq.mliv"

# 650 "src/batSeq.mliv"
# 651 "src/batSeq.mliv"
# 652 "src/batSeq.mliv"
# 653 "src/batSeq.mliv"
# 654 "src/batSeq.mliv"

# 656 "src/batSeq.mliv"
# 657 "src/batSeq.mliv"
# 658 "src/batSeq.mliv"
# 659 "src/batSeq.mliv"
# 660 "src/batSeq.mliv"

# 662 "src/batSeq.mliv"
# 663 "src/batSeq.mliv"
# 664 "src/batSeq.mliv"
# 665 "src/batSeq.mliv"
# 666 "src/batSeq.mliv"
# 667 "src/batSeq.mliv"
# 668 "src/batSeq.mliv"
# 669 "src/batSeq.mliv"
# 670 "src/batSeq.mliv"
# 671 "src/batSeq.mliv"
# 672 "src/batSeq.mliv"
# 673 "src/batSeq.mliv"
# 674 "src/batSeq.mliv"
# 675 "src/batSeq.mliv"

# 677 "src/batSeq.mliv"
# 678 "src/batSeq.mliv"
# 679 "src/batSeq.mliv"
# 680 "src/batSeq.mliv"
# 681 "src/batSeq.mliv"
# 682 "src/batSeq.mliv"
# 683 "src/batSeq.mliv"
# 684 "src/batSeq.mliv"
# 685 "src/batSeq.mliv"
# 686 "src/batSeq.mliv"
# 687 "src/batSeq.mliv"
# 688 "src/batSeq.mliv"
# 689 "src/batSeq.mliv"

# 691 "src/batSeq.mliv"
# 692 "src/batSeq.mliv"
# 693 "src/batSeq.mliv"
# 694 "src/batSeq.mliv"
# 695 "src/batSeq.mliv"

# 697 "src/batSeq.mliv"
# 698 "src/batSeq.mliv"
# 699 "src/batSeq.mliv"
# 700 "src/batSeq.mliv"
# 701 "src/batSeq.mliv"
# 702 "src/batSeq.mliv"
# 703 "src/batSeq.mliv"
# 704 "src/batSeq.mliv"
# 705 "src/batSeq.mliv"
# 706 "src/batSeq.mliv"
# 707 "src/batSeq.mliv"
# 708 "src/batSeq.mliv"
# 709 "src/batSeq.mliv"

# 711 "src/batSeq.mliv"
# 712 "src/batSeq.mliv"
# 713 "src/batSeq.mliv"
# 714 "src/batSeq.mliv"
# 715 "src/batSeq.mliv"
# 716 "src/batSeq.mliv"
# 717 "src/batSeq.mliv"
# 718 "src/batSeq.mliv"
# 719 "src/batSeq.mliv"
# 720 "src/batSeq.mliv"
# 721 "src/batSeq.mliv"

# 723 "src/batSeq.mliv"
# 724 "src/batSeq.mliv"
# 725 "src/batSeq.mliv"
# 726 "src/batSeq.mliv"
# 727 "src/batSeq.mliv"
# 728 "src/batSeq.mliv"
# 729 "src/batSeq.mliv"
# 730 "src/batSeq.mliv"
# 731 "src/batSeq.mliv"
# 732 "src/batSeq.mliv"
# 733 "src/batSeq.mliv"

# 735 "src/batSeq.mliv"
# 736 "src/batSeq.mliv"
# 737 "src/batSeq.mliv"
# 738 "src/batSeq.mliv"
# 739 "src/batSeq.mliv"
# 740 "src/batSeq.mliv"
# 741 "src/batSeq.mliv"
# 742 "src/batSeq.mliv"
# 743 "src/batSeq.mliv"
# 744 "src/batSeq.mliv"
# 745 "src/batSeq.mliv"
# 746 "src/batSeq.mliv"

# 748 "src/batSeq.mliv"
# 749 "src/batSeq.mliv"
# 750 "src/batSeq.mliv"
# 751 "src/batSeq.mliv"
# 752 "src/batSeq.mliv"
# 753 "src/batSeq.mliv"
# 754 "src/batSeq.mliv"
# 755 "src/batSeq.mliv"

# 757 "src/batSeq.mliv"
# 758 "src/batSeq.mliv"
# 759 "src/batSeq.mliv"
# 760 "src/batSeq.mliv"
# 761 "src/batSeq.mliv"
# 762 "src/batSeq.mliv"
# 763 "src/batSeq.mliv"
# 764 "src/batSeq.mliv"

# 766 "src/batSeq.mliv"
# 767 "src/batSeq.mliv"
# 768 "src/batSeq.mliv"
# 769 "src/batSeq.mliv"
# 770 "src/batSeq.mliv"
# 771 "src/batSeq.mliv"
# 772 "src/batSeq.mliv"
# 773 "src/batSeq.mliv"
# 774 "src/batSeq.mliv"
# 775 "src/batSeq.mliv"
# 776 "src/batSeq.mliv"
# 777 "src/batSeq.mliv"
# 778 "src/batSeq.mliv"

# 780 "src/batSeq.mliv"
# 781 "src/batSeq.mliv"
# 782 "src/batSeq.mliv"
# 783 "src/batSeq.mliv"
# 784 "src/batSeq.mliv"
# 785 "src/batSeq.mliv"
# 786 "src/batSeq.mliv"
# 787 "src/batSeq.mliv"
# 788 "src/batSeq.mliv"
# 789 "src/batSeq.mliv"
# 790 "src/batSeq.mliv"
# 791 "src/batSeq.mliv"
# 792 "src/batSeq.mliv"
# 793 "src/batSeq.mliv"
# 794 "src/batSeq.mliv"
# 795 "src/batSeq.mliv"
# 796 "src/batSeq.mliv"

# 798 "src/batSeq.mliv"
# 799 "src/batSeq.mliv"
# 800 "src/batSeq.mliv"
# 801 "src/batSeq.mliv"
# 802 "src/batSeq.mliv"
# 803 "src/batSeq.mliv"
# 804 "src/batSeq.mliv"
# 805 "src/batSeq.mliv"
# 806 "src/batSeq.mliv"
# 807 "src/batSeq.mliv"
# 808 "src/batSeq.mliv"
# 809 "src/batSeq.mliv"
# 810 "src/batSeq.mliv"

# 812 "src/batSeq.mliv"
# 813 "src/batSeq.mliv"
# 814 "src/batSeq.mliv"
# 815 "src/batSeq.mliv"

# 817 "src/batSeq.mliv"
# 818 "src/batSeq.mliv"
# 819 "src/batSeq.mliv"
# 820 "src/batSeq.mliv"
# 821 "src/batSeq.mliv"
# 822 "src/batSeq.mliv"
# 823 "src/batSeq.mliv"
# 824 "src/batSeq.mliv"
# 825 "src/batSeq.mliv"
# 826 "src/batSeq.mliv"
# 827 "src/batSeq.mliv"
# 828 "src/batSeq.mliv"
# 829 "src/batSeq.mliv"
# 830 "src/batSeq.mliv"
# 831 "src/batSeq.mliv"
# 832 "src/batSeq.mliv"
# 833 "src/batSeq.mliv"
# 834 "src/batSeq.mliv"
# 835 "src/batSeq.mliv"
# 836 "src/batSeq.mliv"
# 837 "src/batSeq.mliv"

# 839 "src/batSeq.mliv"
# 840 "src/batSeq.mliv"
# 841 "src/batSeq.mliv"
# 842 "src/batSeq.mliv"
# 843 "src/batSeq.mliv"
# 844 "src/batSeq.mliv"
# 845 "src/batSeq.mliv"
# 846 "src/batSeq.mliv"
# 847 "src/batSeq.mliv"
# 848 "src/batSeq.mliv"
# 849 "src/batSeq.mliv"
# 850 "src/batSeq.mliv"
# 851 "src/batSeq.mliv"
# 852 "src/batSeq.mliv"
# 853 "src/batSeq.mliv"
# 854 "src/batSeq.mliv"

# 856 "src/batSeq.mliv"
# 857 "src/batSeq.mliv"
# 858 "src/batSeq.mliv"
# 859 "src/batSeq.mliv"
# 860 "src/batSeq.mliv"
# 861 "src/batSeq.mliv"
# 862 "src/batSeq.mliv"
# 863 "src/batSeq.mliv"
# 864 "src/batSeq.mliv"
# 865 "src/batSeq.mliv"
# 866 "src/batSeq.mliv"
# 867 "src/batSeq.mliv"
# 868 "src/batSeq.mliv"
# 869 "src/batSeq.mliv"
# 870 "src/batSeq.mliv"
# 871 "src/batSeq.mliv"

# 873 "src/batSeq.mliv"
# 874 "src/batSeq.mliv"
# 875 "src/batSeq.mliv"
# 876 "src/batSeq.mliv"
# 877 "src/batSeq.mliv"
# 878 "src/batSeq.mliv"
# 879 "src/batSeq.mliv"
# 880 "src/batSeq.mliv"

# 882 "src/batSeq.mliv"

# 884 "src/batSeq.mliv"
# 885 "src/batSeq.mliv"
# 886 "src/batSeq.mliv"
# 887 "src/batSeq.mliv"
# 888 "src/batSeq.mliv"
# 889 "src/batSeq.mliv"
